========
your_app
========

Tutorial repository for `"Creating and Distributing a Python Project" <http://thecodeinn.blogspot.com/2015/08/python-project.html>`_.

`Documentation <your_app.rtfd.org>`_
====================================

Documentation can be found here: your_app.rtfd.org

`License <your_app.mit-license.org>`_
=====================================

This project is licensed under the MIT-License.

Authors
=======

Peter Goldsborough & `cat <https://goo.gl/IpUmJn>`_ :heart:

